@@ -1,5 +1,10 @@
 
-# $Id: Ebay.pm,v 2.268 2014-09-02 02:45:24 Martin Exp $
+# $Id: Ebay.pm,v 2.270 2015-06-06 20:45:52 Martin Exp $
+
+package WWW::Search::Ebay;
+
+use strict;
+use warnings;
 
 =head1 NAME
 
@@ -113,11 +118,6 @@ Contributed by Brian Wilson:
 
 =cut
 
-package WWW::Search::Ebay;
-
-use strict;
-use warnings;
-
 use base 'WWW::Search';
 
 use constant DEBUG_DATES => 0;
@@ -127,7 +127,7 @@ use Carp ();
 use CGI;
 use Data::Dumper;  # for debugging only
 use Date::Manip;
-&Date_Init('TZ=US/Pacific') unless (defined($ENV{TZ}) && ($ENV{TZ} ne ''));
+# Date_Init("setdate=now,America/Los_Angeles");
 use HTML::TreeBuilder;
 use LWP::Simple;
 use WWW::Search qw( generic_option strip_tags );
@@ -136,7 +136,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.268 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.270 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -365,6 +365,26 @@ sub _create_description
   return $sDesc;
   } # _create_description
 
+sub _parse_category
+  {
+  my $self = shift;
+  my $oTD = shift;
+  return -1 if ! ref $oTD;
+  my $oA = $oTD->look_down(_tag => 'a');
+  return -1 if ! ref $oA;
+  if (DEBUG_COLUMNS || (1 < $self->{_debug}))
+    {
+    my $s = $oA->as_HTML;
+    print STDERR " DDD   TDcategory's A ===$s===\n";
+    } # if
+  my $sURL = $oA->attr('href') || q{};
+  if ($sURL =~ m/sibeleafcat=(\d+)/)
+    {
+    return $1;
+    } # if
+  return -1;
+  } # _parse_category
+
 sub _parse_price
   {
   my $self = shift;
@@ -394,8 +414,13 @@ sub _parse_price
     return 0;
     # There is a separate backend for searching Auction items!
     } # if
-  if ($oTDprice->look_down(_tag => 'span',
-                          class => 'ebSold'))
+  if (
+      $oTDprice->look_down(_tag => 'span',
+                          class => 'ebSold')
+      ||
+      $oTDprice->look_down(_tag => 'span',
+                          class => 'bold bidsold')
+     )
     {
     # This item sold, even if it had no bids (i.e. Buy-It-Now)
     $hit->sold(1);
@@ -409,6 +434,8 @@ sub _parse_price
   my $iPrice = $oTDprice->as_text;
   print STDERR " DDD   raw iPrice ===$iPrice===\n" if  (DEBUG_COLUMNS || (1 < $self->{_debug}));
   $iPrice =~ s!&pound;!GBP!;
+  $iPrice =~ s!\s*Trending.+!!;
+  $iPrice =~ s!\s*Was.+!!;
   # Convert nbsp to regular space:
   $iPrice =~ s!\240!\040!g;
   # I don't know why there are sometimes weird characters in there:
@@ -690,6 +717,10 @@ sub _get_result_count_elements
                             '_tag' => 'div',
                             id => 'rsc'
                            );
+  push @ao, $tree->look_down( # as of 2015-06
+                            '_tag' => 'span',
+                            class => 'listingscnt'
+                           );
   return @ao;
   } # _get_result_count_elements
 
@@ -893,7 +924,6 @@ sub _parse_tree
     my $hit = new WWW::Search::Result;
     $hit->add_url($self->_cleanup_url($sURL));
     $hit->title($sTitle);
-    $hit->category($iCategory);
     $hit->item_number($iItemNum);
     # This is just to prevent undef warnings later on:
     $hit->bid_count(0);
@@ -911,14 +941,14 @@ sub _parse_tree
       my $s = $oTDsib->as_HTML;
       if ($sColumn eq q{})
         {
-        warn " EEE auction info sibling has no class ==$s==" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
+        warn " WWW auction info sibling has no class ==$s==" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
         } # if
       print STDERR " DDD   looking at TD'$sColumn' ===$s===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
       if ($sColumn =~ m'price')
         {
         next TD unless $self->_parse_price($oTDsib, $hit);
         } # if
-      if ($sColumn =~ m'bids')
+      if (($sColumn =~ m'bids') || ($sColumn =~ m'format'))
         {
         # It is not a fatal error if there are no bids (i.e. buy-it-now)
         $self->_parse_bids($oTDsib, $hit);
@@ -941,10 +971,19 @@ sub _parse_tree
         # we're searching against.  Throw it out:
         next TD;
         }
+      if ($sColumn =~ m'extras')
+        {
+        if ($iCategory < 0)
+          {
+          # We haven't found this item's category.  Look for it here:
+          $iCategory = $self->_parse_category($oTDsib);
+          } # if
+        } # if 'extras'
       # Any other class="" value will cause the <LI> to be ignored.
       } # while
     my $sDesc = $self->_create_description($hit);
     $hit->description($sDesc);
+    $hit->category($iCategory);
     # Clean up / sanity check hit info:
     my ($enddate, $iBids);
     if (
@@ -1145,7 +1184,7 @@ Include parentheses so that $1 becomes the number (with commas is OK).
 
 sub _result_count_pattern
   {
-  return qr'([0-9,]+)\s+(active\s+)?(listing|item|matche?|result)s?(\s+found)?\b';
+  return qr'([0-9,]+)\s+(active\s+)?(listing|item|matche?|result)s?(\s+found)?';
   } # _result_count_pattern
 
 
